@@ -378,6 +378,8 @@ class AgentLifeCycle:
             args.config.config_path + "agent/logs/bunched_logs": {"bind": "/root/.cognicept/agent/logs/bunched_logs", "mode": "rw"}}, "network_mode": "host"}
         object._agent_run_options["remote_intervention_agent"] = {
             "command": "rosrun remote_intervention_agent cognicept_agent_node", "network_mode": "host"}
+        object._agent_run_options["health_aggregator"] = {"command": "roslaunch health_monitoring_aggregator aggregator.launch --wait", "volumes": {
+            args.config.config_path + "health_config.yaml": {"bind": "/home/aggregator_ws/src/health_monitoring_aggregator/config.yml", "mode": "rw"}}, "network_mode": "host"}
 
         if(args.config.is_ssh_enabled()):
             object._agent_run_options["remote_intervention_agent"]["volumes"] = {
