@@ -4,17 +4,13 @@
 # --> Configuration class handles Cognicept configuration
 
 from dotenv import dotenv_values
-from dotenv import load_dotenv
-from dotenv import find_dotenv
 from pathlib import Path
 from Crypto.PublicKey import RSA
 import subprocess
 import os
-import sys
 import re
 import requests
 import getpass
-import time
 
 
 class Configuration:
@@ -96,53 +92,57 @@ class Configuration:
                 Parameters:
                         args: populated argument namespace returned by `argparse.parse_args()`            
         """
-        if(not object._config_loaded):
-            return
-
-        if (not os.access(object.env_path, os.W_OK)):
-            print("Error: You don't have writing permissions for `" +
-                  object.env_path + "`. Run as `sudo` or change file permissions.")
-            return
-        if(args.read):
-            for key, value in object.config.items():
-                print(key + ': "' + value + '"')
-        elif(args.add):
-            new_key = ""
-            while(new_key == ""):
-                new_key = input("Config name: ")
-
-                # if empty, exit
-                if(new_key == ""):
-                    return
-                # check if matches key specs
-                matches = re.match(object._regex_key, new_key)
-                if matches is None:
-                    print(
-                        "Error: Key can be uppercase letters, digits, and the '_'. Try again.")
-                    new_key = ""
-
-            new_value = ""
-            while(new_value == ""):
-                new_value = input("Value: ")
-                if(new_value == ""):
-                    return
-                matches = re.match(r"^.*[\"].*$", new_value)
-                if matches is not None:
-                    print("Error: Value cannot contain '\"'. Try again.")
-                    new_value = ""
-
-            object.config[new_key] = new_value
-        elif(args.ssh):
+        if(args.ssh):
             if object.configure_ssh():
                 print(
                     'SSH config done. To apply changes restart agents using `cognicept restart`.')
+        elif(args.autocomplete):
+            if object.configure_autocomplete():
+                print('Autocomplete setup done')
         else:
-            for key, value in object.config.items():
-                new_value = input(key + "[" + value + "]:")
-                matches = re.match(r"^.*[\"].*$", new_value)
-                if((new_value != "") and (matches == None)):
-                    object.config[key] = new_value
-        object.save_config()
+            if(not object._config_loaded):
+                return
+
+            if (not os.access(object.env_path, os.W_OK)):
+                print("Error: You don't have writing permissions for `" +
+                    object.env_path + "`. Run as `sudo` or change file permissions.")
+                return
+            if(args.read):
+                for key, value in object.config.items():
+                    print(key + ': "' + value + '"')
+            elif(args.add):
+                new_key = ""
+                while(new_key == ""):
+                    new_key = input("Config name: ")
+
+                    # if empty, exit
+                    if(new_key == ""):
+                        return
+                    # check if matches key specs
+                    matches = re.match(object._regex_key, new_key)
+                    if matches is None:
+                        print(
+                            "Error: Key can be uppercase letters, digits, and the '_'. Try again.")
+                        new_key = ""
+
+                new_value = ""
+                while(new_value == ""):
+                    new_value = input("Value: ")
+                    if(new_value == ""):
+                        return
+                    matches = re.match(r"^.*[\"].*$", new_value)
+                    if matches is not None:
+                        print("Error: Value cannot contain '\"'. Try again.")
+                        new_value = ""
+
+                object.config[new_key] = new_value        
+            else:
+                for key, value in object.config.items():
+                    new_value = input(key + "[" + value + "]:")
+                    matches = re.match(r"^.*[\"].*$", new_value)
+                    if((new_value != "") and (matches == None)):
+                        object.config[key] = new_value
+            object.save_config()
 
     def save_config(object):
         """
@@ -471,4 +471,39 @@ class Configuration:
             return False
         except Exception as e:
             print("Cognicept REST API error" + str(e))
-            raise SystemExit()
\ No newline at end of file
+            raise SystemExit()
+
+    def configure_autocomplete(object):
+        """
+
+        Function to setup autcomplate functionality
+                Parameters:
+                        None
+                Returns:
+                        result (bool): True if some step didn't fail
+
+        """
+
+        enable_autocomplete = None
+        while(enable_autocomplete == None):
+            enable_autocomplete = object._interpret_bool_input(
+                input("Enable Autocomplete? (Y/n):"))
+        
+        if (not enable_autocomplete):
+            print("Autocomplete was not configured")
+            return True
+
+        bash_complete_path = "/etc/bash_completion.d/"
+        tmp_path = os.path.expanduser("~") + "/.cognicept/"
+        
+        print("Root access is needed to place bash completition script at `" + bash_complete_path +
+              "' you will be prompted for password.")
+
+        allow_root_access = None
+        while(allow_root_access == None):
+            allow_root_access = object._interpret_bool_input(
+            input("Generate script and give access? (Y/n):"))
+        subprocess.call(['bash', '-c', 'activate-global-python-argcomplete --dest ' + tmp_path])
+        subprocess.call(['sudo', 'bash', '-c', 'mv ' + tmp_path + "python-argcomplete" + " /etc/bash_completion.d/"])
+        print("Please restart the terminal.....")
+        return True
